/************************************************************************/
/* Author: 	Hirotaka Miura.						*/
/* Contact: 	Hirotaka.Miura@gmail.com.				*/
/************************************************************************/

/************************************************************************/
/* 05/05/2011: 	Modified.						*/
/* 04/22/2011: 	Previouly modified.					*/
/* 04/22/2011: 	Created.						*/
/************************************************************************/

/************************************************************************/
/* Program: 	bfs_component().					*/
/* Function: 	Generate component matrix using BFS algorithm.		*/					*/
/************************************************************************/
mata:
real matrix bfs_component(real matrix E,  
  | string scalar nodots){
  /* Declare variables.							*/
  struct matrix_struct scalar z /* Adjacency list return structure.	*/
  real matrix A /* Adjacency list.					*/
  real matrix C /* Component sparse matrix.				*/
  real vector l /* Adjacency list.					*/  
  real vector q /* Queue vector.					*/
  real vector e /* Source-specific distance vector.			*/
  real scalar r /* Read pointer.					*/
  real scalar w /* Write pointer.					*/
  real scalar v /* Current vertex.					*/
  real scalar d /* Distance from source vertex.				*/
  real scalar j /* Column counter.					*/  
  real scalar s /* Source vertex.					*/
  real scalar m /* Total number of nodes in network.			*/
  string scalar o /* Status display string.				*/
  /**********************************************************************/
  /* Begin program.							*/
  /**********************************************************************/
  /* Obtain total number of nodes in network.				*/
  m=max(E[.,(1,2)])    
  /***** Inform user of program starting.				*/
  o="noisily display "+`""""'; stata(o); displayflush()
  o="Component analysis ("+strofreal(m)+" vertices)"
  o="noisily display "+`"""'+o+`"""'
  stata(o); displayflush()
  /* Display dots unless specified not to.				*/
  if(nodots==""){
    o="----+--- 1 ---+--- 2 ---+--- 3 ---+--- 4 ---+--- 5"
    o="noisily display "+`"""'+o+`"""'
    stata(o); displayflush() 
  }
  /***** Setup for loop.						*/
  /* Obtain adjacency list.						*/
  z=adjacency_list(E); A=z.X1
  /* Initialize component matrix.					*/
  C=J(m,m,0)
  /***** Loop through all the nodes.					*/
  for(s=1;s<=m;s++){
    /* Insert source node entry.					*/
    C[s,s]=1; e=J(1,m,.); e[s]=0
    /* Initiate queue array with source vertex.				*/
    q=J(1,m,.); q[1]=s
    /* Set read and write pointers.					*/
    r=1; w=2
    /* Loop while read and write pointers are not equal to each other.	*/
    while(r!=w){    
      /* Read vertex pointed to by read pointer.			*/
      v=q[r]
      /* Increment read pointer.					*/
      ++r
      /* Find distance from source vertex for vertex "v."		*/
      d=e[v]    
      /* Obtain adjacency list of out-neighbors of vertex "v."		*/
      l=A[v,.]
      /* Loop through out-neighbors of vertex "v."			*/
      for(j=1;j<=nonmissing(l);j++){
	/* If distance hasn't been assigned, assign distance.		*/
	if(e[l[j]]==.){
	  /* Assign distance.						*/
	  e[l[j]]=d+1
	  /* Input neighbor into queue vector; increment write pointer.	*/
	  q[w]=l[j]; ++w
	  /* Note connected in component matrix.			*/
	  C[s,l[j]]=1
	}
      }
    }    
    /* Display status unless specified not to.				*/
    if(nodots=="") display_status(m,s)
  }
  /* Notify program is over.						*/
  o="Component analysis completed"
  o="noisily display "+`"""'+o+`"""'
  stata(o); displayflush()  
  /* Return component matrix.						*/
  return(C)
}    
end

