{smcl}
{* *! Stata Graph Library version 1.1.2  06jun2011}{...}
{cmd:help network netsummarize}
{hline}

{title:Title}

{p2colset 5 29 37 2}{...}
{p2col:{hi:network netsummarize} {hline 2}}Postcomputation tool for network{p_end}
{p2colreset}{...}


{title:Syntax}

{p 8 14 2}
{opt netsum:marize} 
  {it:mata_exp}
  {cmd:,}
  {opt g:enerate(newvar_prefix)}
  {opt s:tatistic(stat_name)}

{phang} where {it:stat_name} can be one of

{p2colset 9 31 19 2}{...}
{p2col:{cmdab:mean}} mean(mean({it:mata_exp})'){p_end}
{p2col:{cmdab:min}} min({it:mata_exp}){p_end}
{p2col:{cmdab:max}} max({it:mata_exp}){p_end}
{p2col:{cmdab:sum}} sum({it:mata_exp}){p_end}
{p2col:{cmdab:missing}} missing({it:mata_exp}){p_end}
{p2col:{cmdab:nonmissing}} nonmissing({it:mata_exp}){p_end}
{p2col:{cmdab:rowmean}} mean({it:mata_exp}')'{p_end}
{p2col:{cmdab:rowmin}} rowmin({it:mata_exp}){p_end}
{p2col:{cmdab:rowmax}} rowmax({it:mata_exp}){p_end}
{p2col:{cmdab:rowsum}} rowsum({it:mata_exp}){p_end}
{p2col:{cmdab:rowmissing}} rowmissing({it:mata_exp}){p_end}
{p2col:{cmdab:rownonmissing}} rownonmissing({it:mata_exp}){p_end}
{p2col:{cmdab:colmean}} mean({it:mata_exp})'{p_end}
{p2col:{cmdab:colmin}} colmin({it:mata_exp})'{p_end}
{p2col:{cmdab:colmax}} colmax({it:mata_exp})'{p_end}
{p2col:{cmdab:colsum}} colsum({it:mata_exp})'{p_end}
{p2col:{cmdab:colmissing}} colmissing({it:mata_exp})'{p_end}
{p2col:{cmdab:colnonmissing}} colnonmissing({it:mata_exp})'{p_end}


{title:Description}

{p 4 4 2}
{cmd:netsummarize} merges network statistics to Stata dataset.


{title:Options}

{dlgtab:Main}

{phang}
{opt generate(newvar_prefix)} specifies new variables {it:newvar_prefix}{cmd:_source} and {it:newvar_prefix}{cmd:_target} be generated for {varname:_source} and {varname:_target}, respectively.

{phang}
{opt statistic(stat_name)} specifies statistic to be merged into Stata dataset. 


{title:Remarks}

{pstd}
{it:mata_exp} must be a Mata matrix or a Mata expression and must evaluate to either a scalar, a |{it:V}|x1 column vector, or a |{it:V}|x|{it:V}| matrix. See {helpb mf_sum:[M-5] sum()}, {helpb mf_mean:[M-5] mean()},
{helpb mf_missing:[M-5] missing()}, and {helpb mf_minmax:[M-5] minmax()}.


{title:Example:  Workflow using {cmd:pajek2stata}, {cmd:network}, and {cmd:netsummarize}}

{pstd}Transfer Pajek's .net file into Stata using Rense Corten's {helpb pajek2stata}.{p_end}
{phang2}{com}. pajek2stata using florentine_marriages.net, name(X) clear replace{p_end}
{phang2}{com}. destring var1, replace{p_end}
{txt}
{pstd}Generate new value-label.  See {helpb mf_st_vlexists:[M-5] st_vlexists()}.{p_end}
{phang2}{com}. mata st_vlmodify("vertex_label",st_data(.,"var1"),st_sdata(.,"var2")){p_end}
{res}{txt}
{pstd}Drop vertex label variables and add new variables.{p_end}
{phang2}{com}. drop var1 var2{p_end}
{phang2}{com}. mata (void) st_addvar("double",("source","target")){p_end}
{res}{txt}
{pstd}Add observations.{p_end}
{phang2}{com}. mata st_addobs(rows(X)){p_end}
{res}{txt}
{pstd}Store edge list in Stata.{p_end}
{phang2}{com}. mata st_store(.,("source","target"),X){p_end}
{res}{txt}
{pstd}Assign value label to variables.{p_end}
{phang2}{com}. label values source target vertex_label{p_end}
{txt}
{pstd}Generate degree centrality.{p_end}
{phang2}{com}. network source target, measure(adjacency) name(A,replace){p_end}
{phang2}{com}. netsummarize A/(rows(A)-1), generate(degree) statistic(rowsum){p_end}
{res}{txt}
{pstd}Generate closeness centrality.{p_end}
{phang2}{com}. network source target, measure(distance) name(D,replace){p_end}
{phang2}{com}. netsummarize (rows(D)-1):/rowsum(D), generate(closeness) statistic(rowsum){p_end}
{res}{txt}
{pstd}Generate betweenness centrality.{p_end}
{phang2}{com}. network source target, measure(betweenness) name(b,replace){p_end}
{phang2}{com}. netsummarize b/((rows(b)-1)*(rows(b)-2)), generate(betweenness) statistic(rowsum){p_end}
{res}{txt}
{pstd}Generate eigenvector centrality.{p_end}
{phang2}{com}. network source target, measure(eigenvector) name(e,replace){p_end}
{phang2}{com}. netsummarize e, generate(eigenvector) statistic(rowsum){p_end}
{txt}

{title:Example:  Relational to panel dataset}

{pstd}Load IMF CPIS dataset.{p_end}
{phang2}{com}. use imfcpis, clear{p_end}
{txt}
{pstd}Drop year 2001 - World Bank data is available from 2002 to 2009.{p_end}
{phang2}{com}. drop if year==2001{p_end}
{txt}
{pstd}Compute ineccentricity.{p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. network source target if year==`i', measure(distance) name(D`i',replace) weight(weight) directed nodots{p_end}
{phang2}{com}. netsummarize D`i', generate(ineccentricity`i') statistic(colmax){p_end}
{phang2}{com}. {c )-}{p_end}
{txt}
{pstd}Transfer results to one variable per source and target.{p_end}
{phang2}{com}. generate ineccentricity_source=.{p_end}
{phang2}{com}. label variable ineccentricity_source "ineccentricity"{p_end}
{phang2}{com}. generate ineccentricity_target=.{p_end}
{phang2}{com}. label variable ineccentricity_target "ineccentricity"{p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. quietly replace ineccentricity_source=ineccentricity`i'_source if year==`i'{p_end}
{phang2}{com}. quietly replace ineccentricity_target=ineccentricity`i'_target if year==`i'{p_end}
{phang2}{com}. {c )-}{p_end}
{phang2}{com}. drop *eccentricity200*{p_end}
{txt}
{pstd}Compute eigenvector centrality.{p_end}
{pstd}Generate and use real investment as edge weight.{p_end}
{phang2}{com}. generate realinvestment=investment/(uscpi/100){p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. network source target if year==`i', measure(eigenvector) name(e`i',replace) weight(realinvestment) directed nodots{p_end}
{phang2}{com}. netsummarize e`i', generate(eigenvector`i') statistic(rowsum){p_end}
{phang2}{com}. {c )-}{p_end}
{txt}
{pstd}Transfer results to one variable per source and target.{p_end}
{phang2}{com}. generate eigenvector_source=.{p_end}
{phang2}{com}. label variable eigenvector_source "eigenvector"{p_end}
{phang2}{com}. generate eigenvector_target=.{p_end}
{phang2}{com}. label variable eigenvector_target "eigenvector"{p_end}
{phang2}{com}. forvalues i=2002/2009{c -(}{p_end}
{phang2}{com}. quietly replace eigenvector_source=eigenvector`i'_source if year==`i'{p_end}
{phang2}{com}. quietly replace eigenvector_target=eigenvector`i'_target if year==`i'{p_end}
{phang2}{com}.  {c )-}{p_end}
{phang2}{com}. drop *eigenvector200*{p_end}
{phang2}{com}. rename ineccentricity_target ineccentricity{p_end}
{phang2}{com}. rename eigenvector_target eigenvector{p_end}
{txt}
{pstd}Collapse by target country and year.{p_end}
{phang2}{com}. #d;{p_end}
{phang2}{com}. collapse (sum) weight (sum) investment (sum) realinvestment{p_end}
{phang2}{com}>     (mean) uscpi (mean) ineccentricity (mean) eigenvector{p_end}
{phang2}{com}>     , by(target year){p_end}
{phang2}{com}>   ;{p_end}
{phang2}{com}. #d cr{p_end}
{txt}
{pstd}Merge in World Bank data.  Keep matched observations.{p_end}
{phang2}{com}. rename target country{p_end}
{phang2}{com}. label variable country "Country name"{p_end}
{phang2}{com}. merge 1:1 country year using worldbank, keep(matched) nogenerate{p_end}
{txt}
{pstd}Declare data to be a panel.{p_end}
{phang2}{com}. encode country, generate(country2){p_end}
{phang2}{com}. xtset country2 year{p_end}
{txt}

{title:Reference}

{phang}
Batagelj, V., and A. Mrvar. 2010. Pajek. {browse "http://pajek.imfm.si/doku.php?id=download"}.

{phang}
Corten, R. 2010. PAJEK2STATA: Stata module to import network data in Pajek's.net format. Statistical
Software Components, Boston College Department of Economics.

{phang}
International Monetary Fund. 2007.
{browse "http://www.imf.org/external/np/sta/pi/datarsl.htm"}.
Coordinated Portfolio Investment Survey (CPIS) Data.  Retrieved November, 2010. 

{phang}
Padgett, J. F., and C. K. Ansell. 1993. Robust action and the rise of the Medici, 1400-1434. The American
Journal of Sociology 98(6): 1259-1319.

{phang}
World Bank. 2010. Worldwide Governance Indicators (WGI). {browse "http://data.worldbank.org/data-catalog/worldwide-governance-indicators"}.

{phang}
---. 2011. World Development Indicators (WDI). {browse "http://data.worldbank.org/data-catalog/world-development-indicators"}.


{title:Author}

{phang}
Hirotaka Miura, Economic Research Department, Federal Reserve Bank of San Francisco, San Francisco, CA. 


{title:Also see}

{psee}
{space 2}Help:  {helpb network}, {helpb pajek2stata}, {helpb stata2pajek}, {helpb netplot}, {helpb mata}
{p_end}









